set more off

**************************************************************************
**************************************************************************
**     APPENDIX TABLE 2: ALTERNATIVE MEASURES OF REPEATER EXPOSURE
**************************************************************************
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

* Panel A: indicators for different numbers of repeaters
gen gkclass_nofgrep_1 = (gkclass_nofgrep == 1)
gen gkclass_nofgrep_2 = (gkclass_nofgrep == 2)
gen gkclass_nofgrep_3_5 = ((gkclass_nofgrep > 2) * (gkclass_nofgrep < .))

tab gkclass_nofgrep if gkclasstag == 1

eststo clear

qui eststo: areg gkmath_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) 


* Panel B: class share of repeaters
eststo clear

qui eststo: areg gkmath_std gkclass_shofgrep gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_shofgrep gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_shofgrep gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_shofgrep gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_shofgrep) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


* Panel C: repeater-exposure dummy and class share of repeaters
eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy gkclass_shofgrep gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy gkclass_shofgrep gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy gkclass_shofgrep gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy gkclass_shofgrep gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gkclass_shofgrep) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)
