set more off
set scheme s1mono

**************************************************************************
**************************************************************************
**   ONLINE APPENDIX FIGURE C.2: TEST SCORE IMPACTS FOR SUBSAMPLE OF 
**            STUDENTS OBSERVED WITH NON-COGNITIVE SKILLS
**************************************************************************
**************************************************************************

**************************************************************************
*                          Panel A: math scores                          *
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

* restrict to students observed with non-cognitive skills
keep if g4g8noncog_std != .

tempfile gk g1 g2 g3 y90 y91 y92 y93 y94
foreach g in k 1 2 3 {
	qui areg g`g'math_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
	parmest, level(95) es(N) idstr("currentmath") saving(`"`g`g''"', replace)
}
foreach y in 90 91 92 93 94 {
	qui areg math`y'_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
	parmest, level(95) es(N) idstr("currentmath") saving(`"`y`y''"', replace)
}
drop _all
append using `"`gk'"' `"`g1'"' `"`g2'"' `"`g3'"' `"`y91'"' `"`y92'"' `"`y93'"' `"`y94'"'
keep if parm == "gkclass_ofgrep_dummy"
gen grade = _n - 1
replace grade = grade + 1 if grade > 3
label define grade 0 "K"
label values grade grade

tw (connected estimate grade if idstr == "currentmath", lpattern(solid) lcolor(black) msymbol(S) mcolor(gs2)) ///
   (connected min95 grade if idstr == "currentmath", lpattern(dash_dot) lcolor(black) msymbol(X) mcolor(gs2)) ///
   (connected max95 grade if idstr == "currentmath", lpattern(dash_dot) lcolor(black) msymbol(X) mcolor(gs2)) ///
   , title("Panel A: math", size(medlarge)) yline(0, lcolor(gs6)) xlabel(0(1)8, valuelabel) xtitle("Grade", height(5)) ///
   ylabel(-0.15(0.05)0.15, angle(0)) /*yscale(r(-0.16 0.12))*/ ytitle("Math score standard deviations", height(-7)) ///
   legend(order(1 2 4) label(1 "repeater-exposure effect") label(2 "95% confidence bounds") size(small) textwidth(*6.5)) nodraw name(math, replace)


**************************************************************************
*                         Panel B: reading scores                        *
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk==1 & (gkrepeater == 0 | gkofgrepeater == 1)

* restrict to students observed with non-cognitive skills
keep if g4g8noncog_std!=.

tempfile gk g1 g2 g3 y90 y91 y92 y93 y94
foreach g in k 1 2 3 {
	qui areg g`g'read_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
	parmest, level(95) es(N) idstr("currentread") saving(`"`g`g''"', replace)
}
foreach y in 90 91 92 93 94 {
	qui areg read`y'_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
	parmest, level(95) es(N) idstr("currentread") saving(`"`y`y''"', replace)
}
drop _all
append using `"`gk'"' `"`g1'"' `"`g2'"' `"`g3'"' `"`y91'"' `"`y92'"' `"`y93'"' `"`y94'"'
keep if parm == "gkclass_ofgrep_dummy"
gen grade = _n - 1
replace grade = grade + 1 if grade>3
label define grade 0 "K"
label values grade grade

tw (connected estimate grade if idstr == "currentread", lpattern(solid) lcolor(black) msymbol(S) mcolor(gs2)) ///
   (connected min95 grade if idstr == "currentread", lpattern(dash_dot) lcolor(black) msymbol(X) mcolor(gs2)) ///
   (connected max95 grade if idstr == "currentread", lpattern(dash_dot) lcolor(black) msymbol(X) mcolor(gs2)) ///
   , title("Panel B: reading", size(medlarge)) yline(0, lcolor(gs6)) xlabel(0(1)8, valuelabel) xtitle("Grade", height(5)) ///
   ylabel(-0.15(0.05)0.15, angle(0)) /*yscale(r(-0.16 0.12))*/ ytitle("Reading score standard deviations", height(-7)) ///
   legend(order(1 4) label(1 "repeater-exposure effect") label(4 "95% confidence bounds")) nodraw name(reading, replace)
   
grc1leg math reading, ycommon rows(2) altshrink name(combined, replace)
graph display combined, xsize(4.25) ysize(5.75)
