set more off

**************************************************************************
**************************************************************************
**  ONLINE APPENDIX TABLE C.7: RELATIVE MEASUREMENT OF NON-COG. SKILLS?
**************************************************************************
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)


**************************************************************************
* 4th grade: EITHER no repeater in school OR all repeaters in the school *
* are accounted for (i.e. they were sampled for the non-cognitive skills *
* ratings) and none of them are in the current student's class           *
**************************************************************************

* note: g4schoolid is filled for all students who are still in one of the
* participating schools; hence, all students with 4th-grade non-cognitive
* skills have valid school and class id's
count if g4schoolid != ""
count if g4schoolid != "" & g3schoolid != ""
count if g4pteffr_std != .
count if g4pteffr_std != . & g4schoolid != ""
count if g4pteffr_std != . & g4schoolid != "" & g4classid != .

* generate number of (sampled) repeaters per school
gen gkofgrepeater_w_g4classid = 0
replace gkofgrepeater_w_g4classid = 1 if gkofgrepeater == 1 & g4classid != .
bysort g4schoolid: egen g4school_nofgrep = total(gkofgrepeater == 1) if g4schoolid != ""
bysort g4schoolid: egen g4school_nofgrep_w_g4classid = total(gkofgrepeater_w_g4classid) if g4schoolid != ""

* condition for being included in the restricted sample
gen g4condition = 0
replace g4condition = 1 if g4school_nofgrep == 0
replace g4condition = 1 if g4class_nofgrep == 0 & (g4school_nofgrep == g4school_nofgrep_w_g4classid) & g4school_nofgrep > 0 & g4school_nofgrep < .


**************************************************************************
*                   8th grade: no repeater in school                     *
**************************************************************************

* note: g8schoolid is filled for all students who were in 8th grade in 
* 1994 and who took the state-mandated tests. Almost all students with
* valid non-cognitive skills participated in these tests, and g8schoolid
* is filled for all students with valid non-cognitive skills.
count if g8schoolid == ""
count if g8schoolid == "" & (g8tmathss != . | g8treadss != .)
count if g8pteffr_std != .
count if g8pteffr_std != . & (g8tmathss == . & g8treadss == .)
count if g8pteffr_std != . & g8schoolid==""

* generate number of repeaters per school
bysort g8schoolid: egen g8school_nofgrep = total(gkofgrepeater == 1) if g8schoolid != ""

* condition for being included in the restricted sample
gen g8condition = (g8school_nofgrep == 0) 


**************************************************************************
*                              results                                   *
**************************************************************************

* Panel A: 4th grade, no repeaters in class
eststo clear

qui eststo: areg g4pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & g4condition == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & g4condition == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & g4condition == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & g4condition == 1, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) mtitles("G4 effr" "G4 init" "G4 value" "G4 disc") label r2 nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

* Panel B: 8th grade, no repeaters in school
eststo clear

qui eststo: areg g8pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & g8condition == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & g8condition == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & g8condition == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & g8condition == 1, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) mtitles("G8 effr" "G8 init" "G8 value" "G8 disc") label r2 nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) nonotes
