set more off

**************************************************************************
**************************************************************************
**      ONLINE APPENDIX TABLE C.8: INDIVIDUAL NON-COGNITIVE ITEMS
**************************************************************************
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

* test how grade 8 indices are constructed
gen g8effmath_test = g8pmattn + (6-g8pmmtrl) + g8pmasgn + (6-g8pmlate) + g8pmpers
sum g8effmath_test g8pmeffr
gen g8inimath_test = g8pmmore + g8pmdisc + g8pmdiss
sum g8inimath_test g8pminit
// value: constructed in clean_data.do as (6-g8pmcrts) + (6-g8pmcrit)
gen g8dpnmath_test = g8pmanoy + g8pmrepr + g8pmabus
sum g8dpnmath_test g8pmnonp

* generate averages between math and English for grade 8 individual components
gen g8ptattn = (g8pmattn + g8peattn) / 2
gen g8ptmtrl = (g8pmmtrl + g8pemtrl) / 2
gen g8ptasgn = (g8pmasgn + g8peasgn) / 2
gen g8ptlate = (g8pmlate + g8pelate) / 2
gen g8ptpers = (g8pmpers + g8pepers) / 2
gen g8ptmore = (g8pmmore + g8pemore) / 2
gen g8ptdisc = (g8pmdisc + g8pedisc) / 2	
gen g8ptdiss = (g8pmdiss + g8pediss) / 2
gen g8ptcrts = (g8pmcrts + g8pecrts) / 2	
gen g8ptcrit = (g8pmcrit + g8pecrit) / 2
gen g8ptanoy = (g8pmanoy + g8peanoy) / 2
gen g8ptrepr = (g8pmrepr + g8perepr) / 2
gen g8ptabus = (g8pmabus + g8peabus) / 2
	
* generate standardized variables
foreach s of varlist g4ptattn - g4ptdiss g8ptattn - g8ptabus {
	qui sum `s' if gk == 1 & gkrepeater == 0
	gen `s'_std = (`s' - r(mean)) / sqrt(r(Var))
}
	
* grade 4 effort index
	eststo clear
	
	qui eststo: areg g4ptattn_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) pays attention in class
	qui eststo: areg g4pthwrk_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) completes homework
	qui eststo: areg g4ptothr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) works well with other children
	qui eststo: areg g4ptwork_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) completes assigned seatwork
	qui eststo: areg g4ptpers_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) is persistent when facing difficult problems
	qui eststo: areg g4ptefrt_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) makes sincere effort
	qui eststo: areg g4ptfnsh_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) tries to finish even difficult assignments
	qui eststo: areg g4ptmtrl_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) loses or misplaces materials
	qui eststo: areg g4ptlate_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) comes late to class
	qui eststo: areg g4ptknow_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) doesn't seem to know what's going on in class
	qui eststo: areg g4ptintv_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) doesn't take independent initiative, needs constant help
	qui eststo: areg g4pteasy_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) prefers easy problems
	qui eststo: areg g4ptdsrg_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) is easily discouraged, gives up when facing obstacles
	
	esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

	
* grade 4 initiative index
	eststo clear
	
	qui eststo: areg g4ptries_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) tries to do work thoroughly and well
	qui eststo: areg g4ptdisc_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) participates actively in discussions
	qui eststo: areg g4ptextr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) does more than just the assigned work
	qui eststo: areg g4ptasks_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) asks questions
	qui eststo: areg g4ptrais_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) raises hand to answer a question
	qui eststo: areg g4ptseek_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) seeks reference material on her/his own
	qui eststo: areg g4ptdiss_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) discusses subject with teacher outside of class
	qui eststo: areg g4ptwthd_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) is withdrawn
	
	esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

	
* grade 4 value index
	eststo clear
	
	qui eststo: areg g4ptimpt_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) thinks school is important
	qui eststo: areg g4ptcrit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) is critical of peers who do well in school
	qui eststo: areg g4ptcrts_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) criticizes the subject matter
	
	esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

	
* grade 4 discipline index
	eststo clear
	
	qui eststo: areg g4ptrstl_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) acts restless, unable to sit still
	qui eststo: areg g4ptrepr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) needs reprimanding
	qui eststo: areg g4ptanoy_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) annoys or interferes with peers' work
	qui eststo: areg g4ptalks_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) talks with classmates too much
	
	esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

	
* grade 8 effort index
	eststo clear
	
	qui eststo: areg g8ptattn_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) pays attention in class
	qui eststo: areg g8ptasgn_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) completes assigned seatwork
	qui eststo: areg g8ptpers_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) is persistent when facing difficult problems
	qui eststo: areg g8ptmtrl_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) loses or misplace materials
	qui eststo: areg g8ptlate_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) comes late to class
	
	esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

	
* grade 8 initiative index
	eststo clear
	
	qui eststo: areg g8ptdisc_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) participates actively in discussions
	qui eststo: areg g8ptmore_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) does more than just the assigned work
	qui eststo: areg g8ptdiss_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (+) discusses subject with teacher outside of class

	esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

	
* grade 8 value index
	eststo clear
	
	qui eststo: areg g8ptcrit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) is critical of peers who do well in school
	qui eststo: areg g8ptcrts_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) criticizes the subject matter
	
	esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)
	
	
* grade 8 discipline index
	eststo clear
	
	qui eststo: areg g8ptrepr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) needs reprimanding
	qui eststo: areg g8ptanoy_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) annoys or interferes with peers' work
	qui eststo: areg g8ptabus_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid) // (-) is verbally or physically abusive to teacher
	
	esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)
