set more off


**************************************************************************
**************************************************************************
**                    TABLE 5: HETEROGENEITY ANALYSIS
**************************************************************************
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

global studentbg = "male black gkfreelunch age_years gkoldforgrade"


**************************************************************************
*                         create predicted ability
**************************************************************************

egen gkcomposite = rowmean(gkmath_std gkread_std)
gen predicted_ability=.
levelsof studentid, local(students)
foreach s of local students {
	qui reg gkcomposite male black gkfreelunch age_years gkoldforgrade if gkofgrepeater == 0 & studentid != "`s'"
	qui predict _temp if gkofgrepeater == 0 & studentid == "`s'", xb
	qui replace predicted_ability = _temp if studentid == "`s'"
	qui drop _temp
} 
qui sum predicted_ability if gkofgrepeater == 0
gen predicted_ability_std = (predicted_ability - r(mean)) / sqrt(r(Var))


**************************************************************************
*                                panel A
**************************************************************************

* center age at mean
qui sum age_years if gkofgrepeater == 0
replace age_years = age_years - r(mean)

* generate interaction terms
gen male_X_ofgrep = male * gkclass_ofgrep_dummy
gen black_X_ofgrep = black * gkclass_ofgrep_dummy
gen freelunch_X_ofgrep = gkfreelunch * gkclass_ofgrep_dummy
gen age_years_X_ofgrep = age_years * gkclass_ofgrep_dummy
gen gkoldforgrade_X_ofgrep = gkoldforgrade * gkclass_ofgrep_dummy

eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep) order(gkclass_ofgrep_dummy) ///
	    mtitles("KG math" "G8 math" "NC index" "LT index") label r2 nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) nonotes

		
**************************************************************************
*                                panel B
**************************************************************************
		
gen predicted_ability_X_ofgrep = predicted_ability_std * gkclass_ofgrep_dummy

eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy predicted_ability_X_ofgrep) order(gkclass_ofgrep_dummy) ///
	    mtitles("KG math" "G8 math" "NC index" "LT index") label r2 nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) nonotes


**************************************************************************
*                                panel C
**************************************************************************
		
gen gksmallclass_X_ofgrep = gksmallclass * gkclass_ofgrep_dummy

eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gksmallclass_X_ofgrep) order(gkclass_ofgrep_dummy) ///
	    mtitles("KG math" "G8 math" "NC index" "LT index") label r2 nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) nonotes
