set more off

**************************************************************************
**************************************************************************
**		  TABLE 7: TESTS FOR SELECTIVE ATTRITION FROM THE SAMPLE
**************************************************************************
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

* define non-attritors
gen non_attritor = 0
replace non_attritor = 1 if gkmath_std != . & math94_std != . & hsgraduate != . & hsgpaoverall != . & gkofgrepeater == 0
tab non_attritor


**************************************************************************
*                                panel A
**************************************************************************

foreach v in gkmath_std math94_std g4ptdpln_std g8ptdpln_std hsgpa hsgraduate {
	gen have_`v' = (`v' != .)
}

eststo clear

qui eststo: areg have_gkmath_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg have_math94_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg have_g4ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg have_g8ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg have_hsgpa gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg have_hsgraduate gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg have_hsgraduate $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) mtitles("GK math" "G8 math" "G4 dpln" "G8 dpln" "HS GPA" "HS grad" "ACT/SAT") label r2 nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) nonotes


**************************************************************************
*                                panel B
**************************************************************************

qui sum age_years if gkofgrepeater == 0
replace age_years = age_years - r(mean)

* generate interaction terms
gen male_X_ofgrep = male * gkclass_ofgrep_dummy
gen black_X_ofgrep = black * gkclass_ofgrep_dummy
gen freelunch_X_ofgrep = gkfreelunch * gkclass_ofgrep_dummy
gen age_years_X_ofgrep = age_years * gkclass_ofgrep_dummy
gen gkoldforgrade_X_ofgrep = gkoldforgrade * gkclass_ofgrep_dummy

eststo clear

qui eststo: areg have_gkmath_std gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
test gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep
estadd scalar pvalue = r(p)
qui eststo: areg have_math94_std gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
test gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep
estadd scalar pvalue = r(p)
qui eststo: areg have_g4ptdpln_std gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
test gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep
estadd scalar pvalue = r(p)
qui eststo: areg have_g8ptdpln_std gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
test gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep
estadd scalar pvalue = r(p)
qui eststo: areg have_hsgpa gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
test gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep
estadd scalar pvalue = r(p)
qui eststo: areg have_hsgraduate gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
test gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep
estadd scalar pvalue = r(p)
qui eststo: areg have_hsgraduate $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy male_X_ofgrep black_X_ofgrep freelunch_X_ofgrep age_years_X_ofgrep gkoldforgrade_X_ofgrep) ///
		mtitles("GK math" "G8 math" "G4 dpln" "G8 dpln" "HS GPA" "HS grad" "ACT/SAT") label r2 nogaps se star(* 0.10 ** 0.05 *** 0.01) stats(pvalue, fmt(%9.2f)) varwidth(28) b(3) nonotes

		
**************************************************************************
*                                panel C
**************************************************************************

eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & non_attritor == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & non_attritor == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & non_attritor == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & non_attritor == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpaoverall gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & non_attritor == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & non_attritor == 1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & non_attritor == 1, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) mtitles("GK math" "G8 math" "G4 dpln" "G8 dpln" "HS GPA" "HS grad" "ACT/SAT") label r2 nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) nonotes
